=================
Structure modules
=================

Saxs
====

Description
***********

.. automodule:: maicos.modules.structure.Saxs
    :members:
    :undoc-members:
    :show-inheritance:

Diporder
========

Description
***********

.. automodule:: maicos.modules.structure.Diporder
    :members:
    :undoc-members:
    :show-inheritance:

Debyer
======

Description
***********

.. automodule:: maicos.modules.structure.Debye
    :members:
    :undoc-members:
    :show-inheritance:
